@@ -40,15 +40,7 @@ class ConfiguredBaseTestCase(BaseTestCase):
         self.CONF([], project='seedbox')
         self.CONF.set_override('config_dir', self.base_dir)
         if self.base_dir != self.CONF.config_dir:
-            self.CONF.config_dir = self.base_dir
-
-        # handle fixing the db connection for $config_dir placeholder
-        dbconn = self.CONF.database.connection
-        if '$config_dir' in dbconn:
-            self.CONF.set_override(
-                'connection',
-                dbconn.replace('$config_dir', self.CONF.config_dir),
-                group='database')
+            self.CONF.set_default('config_dir', self.base_dir)
 
     def tearDown(self):
         shutil.rmtree(self.base_dir, ignore_errors=True)
